@@ -50,8 +50,6 @@ static void set_fudge(time_t *seconds)
         *seconds -= fudge;
 }
 
-#ifndef __GNU__
-
 time_t time(time_t *x) {
     static time_t (*libc_time)(time_t *) = NULL;
     time_t res;
@@ -64,10 +62,8 @@ time_t time(time_t *x) {
     return res;
 }
 
-#endif
-
-int __gettimeofday(struct timeval *x, struct timezone *y) {
-    static int (*libc_gettimeofday)(struct timeval *, struct timezone *) = NULL;
+int __gettimeofday(struct timeval *x, void *y) {
+    static int (*libc_gettimeofday)(struct timeval *, void *) = NULL;
     int res;
 
     if(!libc_gettimeofday)
@@ -78,12 +74,10 @@ int __gettimeofday(struct timeval *x, struct timezone *y) {
     return 0;
 }
 
-int gettimeofday(struct timeval *x, struct timezone *y) {
+int gettimeofday(struct timeval *x, void *y) {
     return __gettimeofday(x,y);
 }
 
-#ifndef __GNU__
-
 int clock_gettime(clockid_t x, struct timespec *y) {
     static int (*libc_clock_gettime)(clockid_t, struct timespec*);
     int res;
@@ -95,5 +89,3 @@ int clock_gettime(clockid_t x, struct timespec *y) {
     set_fudge(&y->tv_sec);
     return 0;
 }
-
-#endif
